pyparsing.pyparsing.QuotedString

Package pyparsing :: Module pyparsing :: Class QuotedString |
[frames] | no frames]

# Class QuotedString

source code

       object --+
                |
    ParserElement --+
                    |
                Token --+
                        |
                       QuotedString

Token for matching strings that are delimited by quoting characters.

Instance Methods
__init__(self, quoteChar, escChar=None, escQuote=None, multiline=False, unquoteResults=True, endQuoteChar=None) Defined with the following parameters: | source code
parseImpl(self, instring, loc, doActions=True) | source code
__str__(self) str(x) | source code
Inherited from `Token`: `setName` Inherited from `ParserElement`: `__add__`, `__and__`, `__call__`, `__eq__`, `__getattr__`, `__hash__`, `__invert__`, `__mul__`, `__ne__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__req__`, `__rmul__`, `__rne__`, `__ror__`, `__rsub__`, `__rxor__`, `__sub__`, `__xor__`, `addParseAction`, `checkRecursion`, `copy`, `getException`, `ignore`, `leaveWhitespace`, `parseFile`, `parseString`, `parseWithTabs`, `postParse`, `preParse`, `scanString`, `searchString`, `setBreak`, `setDebug`, `setDebugActions`, `setFailAction`, `setParseAction`, `setResultsName`, `setWhitespaceChars`, `streamline`, `suppress`, `transformString`, `tryParse`, `validate` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `ParserElement`: `enablePackrat`, `resetCache`, `setDefaultWhitespaceChars`

Class Variables
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`, `verbose_stacktrace`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, quoteChar, escChar=None, escQuote=None, multiline=False, unquoteResults=True, endQuoteChar=None) (Constructor) | source code
Defined with the following parameters: quoteChar - string of one or more characters defining the quote delimiting string escChar - character to escape quotes, typically backslash (default=None) escQuote - special quote sequence to escape an embedded quote string (such as SQL's "" to escape an embedded ") (default=None) multiline - boolean indicating whether quotes can span multiple lines (default=False) unquoteResults - boolean indicating whether the matched text should be unquoted (default=True) endQuoteChar - string of one or more characters defining the end of the quote delimited string (default=None => same as quoteChar) Overrides: object.__init__

### parseImpl(self, instring, loc, doActions=True) | source code
Overrides: ParserElement.parseImpl

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)